/*
 * System calls/routines for the L4 Runtime Environment.
 *
 * Copyright (C) 2019 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <l4/re/env.h>
#include <l4/re/protocols.h>
#include <l4/sys/ipc.h>

#include <sys/types.h>

void _exit(int status)
{
  /* See: pkg/l4re-core/uclibc/lib/uclibc/_exit.cc */

  l4re_env_t *env = l4re_env();

  /* Notify any parent task.
     See: pkg/l4re-core/moe/server/src/app_task.cc */

  if (env && l4_is_valid_cap(env->parent))
  {
    /* NOTE: Send a message to env->parent with parameters...
             (L4RE_PROTO_PARENT, 0, status) */
  }

  /* Do not terminate. */

  while (1) l4_ipc_sleep(L4_IPC_NEVER);
}

int getentropy(void *buffer, size_t length)
{
  return -1;
}
